# bioio-types

[![Build Status](https://github.com/bioio-devs/bioio-types/workflows/CI/badge.svg)](https://github.com/bioio-devs/bioio-types/actions)
[![Documentation](https://github.com/bioio-devs/bioio-types/workflows/Documentation/badge.svg)](https://bioio-devs.github.io/bioio-types)

Typing, base classes, and more for BioIO projects.

---

## Installation

**Stable Release:** `pip install bioio-types`<br>
**Development Head:** `pip install git+https://github.com/bioio-devs/bioio-types.git`

## Quickstart

```python
from bioio_types import example

print(example.str_len("hello"))  # prints 5
```

## Documentation

For full package documentation please visit [bioio-devs.github.io/bioio-types](https://bioio-devs.github.io/bioio-types).

## Development

See [CONTRIBUTING.md](CONTRIBUTING.md) for information related to developing the code.

**BSD License**
